"""Copyright (c) 2026 Giordon Stark. All rights reserved.

ami-mcp: MCP Server for ATLAS AMI metadata interface
"""

from __future__ import annotations

__version__ = "0.1.0"

__all__ = ["__version__"]
